package gregapi.render;

import gregapi.old.Dyes;
import gregapi.old.interfaces.IColorModulationContainer;
import net.minecraft.block.Block;
import net.minecraft.client.renderer.RenderBlocks;

/** 
 * @author Gregorius Techneticies
 */
public class BlockTextureDefault implements ITexture, IColorModulationContainer {
	private final IIconContainer mIconContainer;
	
	/**
	 *  DO NOT MANIPULATE THE VALUES INSIDE THIS ARRAY!!!
	 *  
	 *  Just set this variable to another different Array instead.
	 *  Otherwise some colored things will get Problems.
	 */
	public short[] mRGBa;
	
	private final boolean mAllowAlpha, mUseMaxBrightness;
	
	public BlockTextureDefault(IIconContainer aIcon, short[] aRGBa, boolean aAllowAlpha, boolean aUseMaxBrightness) {
		if (aRGBa.length != 4) throw new IllegalArgumentException("RGBa doesn't have 4 Values @ BlockTextureDefault");
		mIconContainer = aIcon;
		mUseMaxBrightness = aUseMaxBrightness;
		mAllowAlpha = aAllowAlpha;
		mRGBa = aRGBa;
	}
	
	public BlockTextureDefault(IIconContainer aIcon, short[] aRGBa, boolean aAllowAlpha) {
		this(aIcon, aRGBa, false, false);
	}
	
	public BlockTextureDefault(IIconContainer aIcon, short[] aRGBa) {
		this(aIcon, aRGBa, false, false);
	}
	
	public BlockTextureDefault(IIconContainer aIcon) {
		this(aIcon, Dyes._NULL.mRGBa, false);
	}
	
	@Override
	public void renderXPos(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderXPos(mIconContainer.getIcon(0), mRGBa, mAllowAlpha, mUseMaxBrightness, aRenderer, aBlock, aX, aY, aZ, mUseMaxBrightness?240:aBrightness);
	}
	
	@Override
	public void renderXNeg(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderXNeg(mIconContainer.getIcon(0), mRGBa, mAllowAlpha, mUseMaxBrightness, aRenderer, aBlock, aX, aY, aZ, mUseMaxBrightness?240:aBrightness);
	}
	
	@Override
	public void renderYPos(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderYPos(mIconContainer.getIcon(0), mRGBa, mAllowAlpha, mUseMaxBrightness, aRenderer, aBlock, aX, aY, aZ, mUseMaxBrightness?240:aBrightness);
	}
	
	@Override
	public void renderYNeg(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderYNeg(mIconContainer.getIcon(0), mRGBa, mAllowAlpha, mUseMaxBrightness, aRenderer, aBlock, aX, aY, aZ, mUseMaxBrightness?240:aBrightness);
	}
	
	@Override
	public void renderZPos(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
    	ITexture.Util.renderZPos(mIconContainer.getIcon(0), mRGBa, mAllowAlpha, mUseMaxBrightness, aRenderer, aBlock, aX, aY, aZ, mUseMaxBrightness?240:aBrightness);
	}
	
	@Override
	public void renderZNeg(RenderBlocks aRenderer, Block aBlock, int aX, int aY, int aZ, int aBrightness) {
		ITexture.Util.renderZNeg(mIconContainer.getIcon(0), mRGBa, mAllowAlpha, mUseMaxBrightness, aRenderer, aBlock, aX, aY, aZ, mUseMaxBrightness?240:aBrightness);
	}
	
	@Override
	public short[] getRGBA() {
		return mRGBa;
	}

	@Override
	public boolean isValidTexture() {
		return mIconContainer != null;
	}
}